-- *****************************************************************************
-- *
-- * Licensed Materials - Property of IBM
-- * 5724-C40
-- * (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- *		
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with
-- * IBM Corp.
-- *
-- *****************************************************************************

----------------------------------------------------------------------------------
-- Here we perform an incremental extract using RAW sequence numbers to control
-- the extraction window; the source table is DM_METRICS and is located on an
-- DB2 RIM Database (ODBC Src=db2_rim); the target table is AMW.STAGE_DM_METRICS
-- and is located on a target DB2 Database (ODBC Tgt=twh_cdw).
----------------------------------------------------------------------------------
--
-- //////////////// drop temporary table to hold the extract window
-- //////////////// at: db2_rim
--
--#IGNORE_ERROR 
DROP TABLE AMW.temp_extract_control;
--
-- //////////////// create temporary table to hold the extract window
-- //////////////// at: db2_rim
--
CREATE TABLE AMW.temp_extract_control (
  extctl_from_rawseq   CHAR(10) FOR BIT DATA NOT NULL,
  extctl_to_rawseq     CHAR(10) FOR BIT DATA NOT NULL )
;
--
-- //////////////// get the from_rawseq from the extract_control in the CDW
-- //////////////// from: twh_cdw to: db2_rim
--
--#INSERT_INTO_SOURCE
INSERT INTO AMW.temp_extract_control
SELECT
  extctl_from_rawseq,
  x'00000000000000000000'
FROM 
  TWG.Extract_Control
WHERE
  extctl_source='DM_METRICS' AND
  extctl_target='AMW.STAGE_DM_METRICS'
;
-- //////////////// update extctl_to_rawseq with the max of twh_insert_seq
-- //////////////// at: db2_rim
--
UPDATE AMW.temp_extract_control
  SET extctl_to_rawseq = (SELECT MAX(twh_insert_seq) FROM twh_dm_metrics)
;
-- //////////////// drop the staging table in twh_cdw (this is faster then deleting all records)
-- //////////////// at: twh_cdw
--
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR          
DROP TABLE AMW.stage_dm_metrics
;
-- //////////////// create the stage table in twh_cdw according to the predefined template
-- //////////////// at: twh_cdw
--
--#EXECUTE_AT_TARGET
CREATE TABLE AMW.stage_dm_metrics LIKE AMW.stage_dm_metrics_template
;
-- //////////////// Dropping the table AMW.stage_dm_metrics makes inoperative the trigger 
-- //////////////// responsible to insert the metric_id unique sequence number.
-- //////////////// Issuing a CREATE TRIGGER statement with the same trigger-name 
-- //////////////// as the inoperative trigger will cause that inoperative trigger 
-- //////////////// to be replaced with a warning (SQLSTATE 01595), so we need to
-- //////////////// instruct the execsql to IGNORE_ERROR.
--
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
CREATE TRIGGER AMW.metric_id_trig NO CASCADE 
  BEFORE INSERT ON AMW.stage_dm_metrics  
  REFERENCING  NEW AS N  
  FOR EACH ROW 
  MODE DB2SQL 
  SET N.metric_id = NEXTVAL FOR AMW.metric_id_seq
;
-- //////////////// perform the extraction from the DM_METRICS table to the staging
-- //////////////// table AMW.stage_dm_metrics in the CDW database.
--
-- //////////////// from: db2_rim to: twh_cdw
--
-- //////////////// NOTE: the constant metric_id value selected from the DM_METRICS
-- //////////////// table is always overridden by the unique sequence number provided
-- //////////////// by the before insert trigger AMW.metric_id_trig
--
--#INSERT_INTO_TARGET
INSERT INTO AMW.stage_dm_metrics 
SELECT
  0 AS metric_id,
  D.COLLECTION_DATE, D.HOSTNAME, D.ENDPOINT, 
  D.PROFILE_COLLECTION, D.PROBE_COLLECTION, 
  D.PROBE, D.PROBE_DESC, D.PROBE_ARG, 
  D.MIN_VALUE_00, D.MAX_VALUE_00, D.AVG_VALUE_00, 
  D.MIN_VALUE_01, D.MAX_VALUE_01, D.AVG_VALUE_01,
  D.MIN_VALUE_02, D.MAX_VALUE_02, D.AVG_VALUE_02,
  D.MIN_VALUE_03, D.MAX_VALUE_03, D.AVG_VALUE_03,
  D.MIN_VALUE_04, D.MAX_VALUE_04, D.AVG_VALUE_04,
  D.MIN_VALUE_05, D.MAX_VALUE_05, D.AVG_VALUE_05,
  D.MIN_VALUE_06, D.MAX_VALUE_06, D.AVG_VALUE_06,
  D.MIN_VALUE_07, D.MAX_VALUE_07, D.AVG_VALUE_07,
  D.MIN_VALUE_08, D.MAX_VALUE_08, D.AVG_VALUE_08,
  D.MIN_VALUE_09, D.MAX_VALUE_09, D.AVG_VALUE_09,
  D.MIN_VALUE_10, D.MAX_VALUE_10, D.AVG_VALUE_10,
  D.MIN_VALUE_11, D.MAX_VALUE_11, D.AVG_VALUE_11,
  D.MIN_VALUE_12, D.MAX_VALUE_12, D.AVG_VALUE_12,
  D.MIN_VALUE_13, D.MAX_VALUE_13, D.AVG_VALUE_13,
  D.MIN_VALUE_14, D.MAX_VALUE_14, D.AVG_VALUE_14,
  D.MIN_VALUE_15, D.MAX_VALUE_15, D.AVG_VALUE_15,
  D.MIN_VALUE_16, D.MAX_VALUE_16, D.AVG_VALUE_16,
  D.MIN_VALUE_17, D.MAX_VALUE_17, D.AVG_VALUE_17,
  D.MIN_VALUE_18, D.MAX_VALUE_18, D.AVG_VALUE_18,
  D.MIN_VALUE_19, D.MAX_VALUE_19, D.AVG_VALUE_19,
  D.MIN_VALUE_20, D.MAX_VALUE_20, D.AVG_VALUE_20,
  D.MIN_VALUE_21, D.MAX_VALUE_21, D.AVG_VALUE_21,
  D.MIN_VALUE_22, D.MAX_VALUE_22, D.AVG_VALUE_22,
  D.MIN_VALUE_23, D.MAX_VALUE_23, D.AVG_VALUE_23,
  MIN_DAILY_VALUE, MAX_DAILY_VALUE, AVG_DAILY_VALUE,
  MIN_HOURLY_AVG, MAX_HOURLY_AVG,
  T.TWH_GMTOFFSET_MIN
FROM 
  DM_METRICS D,
  TWH_DM_METRICS T,
  AMW.temp_extract_control ec
WHERE
  D.COLLECTION_DATE = T.COLLECTION_DATE AND
  D.HOSTNAME = T.HOSTNAME AND
  D.ENDPOINT = T.ENDPOINT AND
  D.PROFILE_COLLECTION = T.PROFILE_COLLECTION AND 
  D.PROBE_COLLECTION = T.PROBE_COLLECTION AND
  D.PROBE = T.PROBE AND
  D.PROBE_ARG = T.PROBE_ARG AND
  T.TWH_INSERT_SEQ > ec.extctl_from_rawseq AND  
  T.TWH_INSERT_SEQ <= ec.extctl_to_rawseq
;
--
-- //////////////// sample check for invalid data if multi customer support is implemented
--
-- //////////////// at: twh_cdw 
--
--#EXECUTE_AT_TARGET
INSERT INTO AMW.Invalid_Data
SELECT *
  FROM AMW.stage_dm_metrics N
 WHERE NOT EXISTS ( SELECT 1 
                      FROM AMW.CUST_LOOKUP CUST_LOOKUP
                     WHERE CUST_LOOKUP.VALUE = N.HOSTNAME OR 
                           CUST_LOOKUP.VALUE = '@' ) 
       OR 
       NOT EXISTS ( SELECT 1 
                      FROM AMW.CENTR_LOOKUP CENTR_LOOKUP
                     WHERE CENTR_LOOKUP.VALUE = N.HOSTNAME OR 
                           CENTR_LOOKUP.VALUE = '@' )
;
--
-- //////////////// drop to_rawseq temp table in CDW
-- //////////////// at: twh_cdw 
--
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR          
DROP TABLE AMW.temp_to_rawseq
;
-- //////////////// create to_rawseq temp table in CDW
-- //////////////// at: twh_cdw
--
--#EXECUTE_AT_TARGET
CREATE TABLE AMW.temp_to_rawseq (
  extctl_to_rawseq   CHAR(10) FOR BIT DATA NOT NULL ) 
;
-- //////////////// copy to_rawseq value into temp table in CDW
-- //////////////// from: db2_rim to: twh_cdw
--
--#INSERT_INTO_TARGET
INSERT INTO AMW.temp_to_rawseq 
SELECT extctl_to_rawseq FROM AMW.temp_extract_control
;
-- //////////////// update extract control with to_rawseq value
-- //////////////// at: twh_cdw
--
--#EXECUTE_AT_TARGET
UPDATE TWG.Extract_Control
  SET extctl_to_rawseq = (SELECT extctl_to_rawseq FROM AMW.temp_to_rawseq)
WHERE
  extctl_source='DM_METRICS' AND
  extctl_target='AMW.STAGE_DM_METRICS'
;
-- //////////////// write extract info to extract log table; this fires the trigger
-- //////////////// TWG.extract_ctl_upd that updates the extract control table to 
-- //////////////// close the window
-- 
--#EXECUTE_AT_TARGET
INSERT INTO TWG.Extract_Log
SELECT 
  extctl_source, extctl_target,
  current timestamp - current timezone,
  extctl_from_rawseq, extctl_to_rawseq,
  extctl_from_intseq, extctl_to_intseq,
  extctl_from_dttm, extctl_to_dttm
FROM
  TWG.Extract_Control ec
WHERE
  ec.extctl_source='DM_METRICS' AND
  ec.extctl_target='AMW.STAGE_DM_METRICS' 
;

