#!/bin/sh
#########################################################################
#------------------------------------------------------------------------
#
# 5724-C40 	 
# (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#
#   File Information: Common/src/tedw_app/amw/pkg/v512/misc/amw_after.sh, tmnt_etl, tmnt_5.1.1_FP06, DM040226E
#   Revision: 1.1
#   Date: 3/4/04 16:54:07
#
#------------------------------------------------------------------------
#
# Desc:
#
# Command Line Args:
#       1 = the path and name of the TWH Application config file
#       2 = Application working directory or install base directory
#               $TWH_TOPDIR/apps/ava_code_for_app/vapp_version (look at install tree)
#
# Required Config File:
#       twh_app_install.cfg
#
# Installation Logs (Default names):
#       A log will be generated for this scirpt called <ava>_after.sh.log
#
#
# Required Env Vars:
#       None.
#
# Return Codes:
#       0 = Success
#       255 = Failure
#
# Interpreter Required:
#       NT/2000 = BASH
#       Unix    = SH (Bourne Shell)
#
#
# Message Types:
#       (I) - Informational
#       (W) - Warning
#       (F) - Fatal
#
# Install Steps Required Before this Script Executes:
#       6 - TWH Core tools and application components must be
#           successfully installed
#
# Note - Caution needs to be taken for NT paths that have a space.  This
#        is a limitation that requires double quoting around all
#        variables that contain a path.  Testing should be done to ensure
#        this script runs with a space in any of the paths that are used.
#########################################################################
#


###

# Pulls in the generic shared routines
# Note the first 50 return codes reseved for the gen routines
include_gen_routines()
{
echo "==> Including Generic Routines"
# Set context for generic routines
if [ -z "$TWH_APP_CONTEXT" ]; then
  TWH_APP_CONTEXT=$TRUE; export TWH_APP_CONTEXT
fi

# TWH_TOPDIR needs to always be in the environment
if [ -z "$TWH_TOPDIR" ]; then
  echo "      (F) Could not locate Env var TWH_TOPDIR"
  exit 255
fi

# Set path to gen routines
gen_path="$TWH_TOPDIR/install/bin"

# Confirm file
if [ ! -r "$gen_path"/twh_gen_routines.sh ]; then
  echo "      (F) Could not locate the twh_gen_routines.sh file."
  echo "          Path specified is ($gen_path)"
  exit 255
fi

# pull in the generic routines
. "$gen_path"/twh_gen_routines.sh

echo "      (I) Done including Generic Routines"
return 0;
}



#
set_private_program_vars()
{
APP_SOURCE_SQL_SCRIPTS="$APP_WORK_DIR/misc"     # path to sql scripts that are being executed

TRUE=1
FALSE=0

return 0;
}


###


#
update_selections()
{
echo "==> Updating RPI.REPORTS Selections"

echo "==> Testing connection to Control Database"
gr_test_connection "$TWH_CTRL_DB" "$COPT_CTRL_DB2USER" "$COPT_CTRL_DB2PASS";

echo "==> Updating Control Database Configuration"
  gr_build_exec_script "$TWH_CTRL_DB" "$APP_SOURCE_SQL_SCRIPTS" upddbm.sql $COPT_CTRL_TYPE $CONN_TYPE_CONNECT;
  gr_exec_sql_script "$TWH_CTRL_DB" $TRUE;

# After update must restart DB2
# Stop services first
echo "==> Stopping DB2 DWC NT services"
err_txt=`$DB2REGI 16 2>&1 `
if [ $? -ne 0 ]; then
  echo "==> (F) Failed to stop NT Service vwkernel and vwlogger"
  echo "        Error is:"
  echo "        $err_txt"
  echo "        Exiting..."
  exit 86
fi

# Stop DB2
echo "==> Stopping DB2"
err_txt=`$DB2CMD db2stop force 2>&1 `
if [ $? -ne 0 ]; then
  blah=`echo $err_txt | grep -i $sql_db_not_started `
  if [ $? -eq 0 ]; then
    :;                  # If db not started that is OK
  else
    echo "==> (F) Failed to stop DB2."
    echo "        Error is:"
    echo "        $err_txt"
    echo "        Exiting..."
    exit 87
  fi
fi

# Start DB2
echo "==> Starting DB2"
err_txt=`$DB2CMD db2start 2>&1 `
# Removed for defect 131629
#if [ $? -ne 0 ]; then
#  echo "      (F) Failed to start DB2."
#  echo "          Error is:"
#  echo "          $err_txt"
#  echo "          Exiting..."
#  exit 88
#fi

# Have to do this again in case db2bp thread was forced
err_txt=`$DB2EXEC_LOG connect to "$TWH_CTRL_DB" user "$COPT_CTRL_DB2USER" using "$COPT_CTRL_DB2PASS" 2>&1 `
if [ $? -ne 0 ]; then
  echo "      (F) Unable to connect to database ($TWH_CTRL_DB)."
  echo "          Error is:"
  echo "          $err_txt"
  echo "          Exiting..."
  exit 91
fi

echo "==> Testing connection to Control Database"
gr_test_connection "$TWH_CTRL_DB" "$COPT_CTRL_DB2USER" "$COPT_CTRL_DB2PASS";

# Start services (logger has to be first!)
echo "==> Starting DB2 DWC NT services"
blah=`net start vwlogger `
if [ $? -ne 0 ]; then
  echo "      (F) Failed to start NT Service vwlogger"
  echo "          Exiting..."
  exit 94
fi

echo "==> Updating Selections in RRI.Reports"
  gr_build_exec_script "$TWH_CTRL_DB" "$APP_SOURCE_SQL_SCRIPTS" updsel.sql $COPT_CTRL_TYPE $CONN_TYPE_CONNECT;
  gr_exec_sql_script "$TWH_CTRL_DB" $TRUE;

echo "==> Done updating RPI.REPORTS Selections"
return 0;
}


############
### Main ###
############

TWH_CONFIG_FILE="$1"                    # config file to read db/user/pwd etc.
APP_WORK_DIR="$2"                       # Installed WD - $TWH_TOPDIR/apps/avacode/vappversion

echo "==> Starting $0"

# Bring in the generic routines
include_gen_routines;

# Now execute main functions
if [ -n "$TWH_CONFIG_FILE" -a -n "$APP_WORK_DIR" ]; then
  gr_set_interp;
  gr_read_config_file;
  gr_set_program_vars;
  gr_extend_path;
  gr_check_user;
  set_private_program_vars;
  # In a 1.2 environment, the TWH_RPI_HOST variable is still passed to 1.1 scripts, but since 
  # there is no RPI, the value is always set to RPI_NULL_HOST. We indirectly check the TEDW version
  # using this environment variable and apply the fix on the RPI.* tables only if it is at 1.1 level
  if [ "x$TWH_RPI_HOST" != "xRPI_NULL_HOST" ]; then
    echo "You are installing on TEDW 1.1, an update of the RPI tables is required!"
    gr_test_db2exec;
    update_selections;
  else
    echo "You are installing on TEDW 1.2, there are no RPI tables to be updated!"
  fi  
  
else
  echo "      (F) The configuration file was not passed as the required argument."
  echo "          Usage: <ava>_after.sh name_of_config_file application_install_base_dir"
  exit 255
fi


echo "==> Completed executing script"

exit 0
